# biotope

| |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|---| |
| Package | [![Latest PyPI Version](https://img.shields.io/pypi/v/biotope.svg)](https://pypi.org/project/biotope/) [![Supported Python Versions](https://img.shields.io/pypi/pyversions/biotope.svg)](https://pypi.org/project/biotope/) [![Documentation](https://readthedocs.org/projects/biotope/badge/?version=latest)](https://biotope.readthedocs.io/en/latest/?badge=latest)                                                                                                                                                                              |
| Meta | [![MIT](https://img.shields.io/pypi/l/biotope.svg)](LICENSE) [![Code of Conduct](https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg)](.github/CODE_OF_CONDUCT.md) [![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/) [![Code Style Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black) [![Linting: Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) |
| Automation |                                                                                                                                                                                                                                                                                                                                                                                                                                       |

_CLI integration for BioCypher ecosystem packages_

## Copyright

- Copyright © 2025 Sebastian Lobentanzer.
- Free software distributed under the [MIT License](./LICENSE).
